/*****************************************************************************
 * Name:      converterbase.h
 * Purpose:   Converter base class for conversion
 * Created:   2007-04-26
 * Copyright: 2007,2008 Dominik Wagenfuehr <dominik.wagenfuehr@deesaster.org>
 * License:   GPLv3
 *****************************************************************************/

/**
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef CONVERTERBASE_H
#define CONVERTERBASE_H

#include <wx/arrstr.h>

/// Converter Base Class
/**
 * This class converts the text file.
 */
class ConverterBase
{
    public:
        /// Option identifier.
        enum OptionID
        {
            ID_OPTION_NONE,   ///< no specific conversion.
            ID_OPTION_UU,     ///< ubuntuusers-specific conversion.
            ID_OPTION_BLOG,   ///< own-blog-specific conversion.
        };

        /// Constructor
        /**
         * Assign text to this class.
         * Creates a deep copy!
         */
        ConverterBase(const wxArrayString& text);

        /// Return text file.
        const wxArrayString& GetText(void) const;

        /// Convert text from HTML to BB-Code.
        void ConvertHTML2BB(const OptionID option);

        /// Convert text from HTML to MoinMoin.
        void ConvertHTML2Moin(const OptionID option);

        /// Convert text from BB-Code to HTML.
        void ConvertBB2HTML(const OptionID option);

        /// Convert text from BB-Code to BB-Code.
        void ConvertBB2Moin(const OptionID option);

        /// Convert text from MoinMoin to HTML.
        void ConvertMoin2HTML(const OptionID option);

        /// Convert text from MoinMoin to BB-Code.
        void ConvertMoin2BB(const OptionID option);

    private:
        /// Set new text, ignore double line breaks
        void Set(const wxArrayString& text);

        /// Text file.
        wxArrayString m_text;
};

#endif // CONVERTERBASE_H
